@@ -93,7 +93,7 @@ void OneFichier::checkUrlIsValid() {
     }
     else {
         QString response(reply->readAll());
-        QString fileName = response.section("File name :</th><td>", 1, 1).section('<', 0, 0);
+        QString fileName = response.section("Filename :</th><td>", 1, 1).section('<', 0, 0);
 
         if (fileName.isEmpty()) {
             emit urlChecked(false);
@@ -142,7 +142,7 @@ void OneFichier::onWebPageDownloaded() {
             request.setUrl(QUrl(re.cap()));
             emit downloadRequestReady(request);
         }
-        else if (response.contains("you can download only one file at a time")) {
+        else if (response.contains("you must wait up to 15 minutes between each download")) {
             this->startWait(300000);
             this->connect(this, SIGNAL(waitFinished()), this, SLOT(onWaitFinished()));
         }
@@ -158,7 +158,7 @@ void OneFichier::getDownloadLink(const QUrl &url) {
     QNetworkRequest request(url);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     request.setRawHeader("Accept-Language", "en-GB,en-US;q=0.8,en;q=0.6");
-    QNetworkReply *reply = this->networkAccessManager()->post(request, QByteArray("b=1&submit=Download+the+file"));
+    QNetworkReply *reply = this->networkAccessManager()->post(request, QByteArray("sub=1&submit=Download"));
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkDownloadLink()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
@@ -179,7 +179,7 @@ void OneFichier::checkDownloadLink() {
     else {
         QString response(reply->readAll());
 
-        if (response.contains("you can download only one file at a time")) {
+        if (response.contains("you must wait up to 15 minutes between each download")) {
             this->startWait(300000);
             this->connect(this, SIGNAL(waitFinished()), this, SLOT(onWaitFinished()));
         }
